@@ -35,7 +35,7 @@ func TestCalculateSHA256s(t *testing.T) {
 		content  = []byte("temporary file's content")
 		checksum = sha256.Sum256(content)
 	)
-	if err = os.WriteFile(location, content, 0666); err != nil {
+	if err = os.WriteFile(location, content, 0o666); err != nil {
 		t.Fatal(err)
 	}
 
